@@ -10,7 +10,7 @@ setAs('data.frame', 'SpatialPolygons',
 			pp <- list()
 			for (j in 1:length(p)) {
 				ss <- s[s$part==p[j], ]
-				pol <- Polygon(as.matrix(ss)[,5:6])
+				pol <- Polygon( as.matrix(ss[,c('x', 'y')] ))
 				if (ss$hole[1]) {
 					pol@hole <- TRUE
 				}
@@ -26,7 +26,7 @@ setAs('data.frame', 'SpatialPolygons',
 
 setAs('data.frame', 'SpatialPolygonsDataFrame',
 	function(from) {
-		x <- as(from, 'SpatialPolygons')
+		x <- methods::as(from, 'SpatialPolygons')
 		if (ncol(from) > 6) {
 			d <- unique(from[, -c(2:6), drop=FALSE])
 			rownames(d) <- d$object
@@ -51,7 +51,7 @@ setAs('data.frame', 'SpatialLines',
 			pp <- list()
 			for (j in 1:length(p)) {
 				ss <- s[s$part==p[j], ]
-				ln <- Line(as.matrix(ss)[,c('x', 'y')])
+				ln <- Line(as.matrix(ss[,c('x', 'y')]))
 				pp[[j]] <- ln
 			}
 			sp[[i]] <- Lines(pp, as.character(i))
@@ -63,7 +63,7 @@ setAs('data.frame', 'SpatialLines',
 
 setAs('data.frame', 'SpatialLinesDataFrame',
 	function(from) {
-		x <- as(from, 'SpatialLines')
+		x <- methods::as(from, 'SpatialLines')
 		if (ncol(from) > 5) {
 			d <- unique(from[, -c(2:5), drop=FALSE])
 			rownames(d) <- d$object
