@@ -12,7 +12,7 @@
 	if (nx == 1 & ny == 1) {
 		return(m)
 	} else {
-		x <- raster(m, xmn=0, xmx=nx*rs[1], ymn=0, ymx=ny*rs[2], crs='+proj=utm +zone=1')
+		x <- raster(m, xmn=0, xmx=nx*rs[1], ymn=0, ymx=ny*rs[2], crs=NA)
 		d <- as.matrix(distance(x)) <= d
 		d / sum(d)
 	}
@@ -32,7 +32,7 @@
 	m <- matrix(ncol=nx, nrow=ny)
 	xr <- (nx * rs[1]) / 2
 	yr <- (ny * rs[2]) / 2
-	r <- raster(m, xmn=-xr[1], xmx=xr[1], ymn=-yr[1], ymx=yr[1], crs='+proj=utm +zone=1')
+	r <- raster(m, xmn=-xr[1], xmx=xr[1], ymn=-yr[1], ymx=yr[1], crs=NA)
 	p <- xyFromCell(r, 1:ncell(r))^2
 # according to http://en.wikipedia.org/wiki/Gaussian_filter
 	m <- 1/(2*pi*sigma^2) * exp(-(p[,1]+p[,2])/(2*sigma^2))
