@@ -14,20 +14,20 @@
 
 .plotSpace <- function(asp=1, legend.mar = 3.1, legend.width = 0.5, legend.shrink = 0.5) {
 	
-	par <- par()
-	char.size <- par$cin[1] / par$din[1]
-    offset <- char.size * par$mar[4] 
+	pars <- graphics::par()
+	char.size <- pars$cin[1] / pars$din[1]
+    offset <- char.size * pars$mar[4] 
     legend.width <- char.size * legend.width
     legend.mar <- legend.mar * char.size
 
-	legendPlot = par$plt
+	legendPlot <- pars$plt
 	legendPlot[2] <- 1 - legend.mar
     legendPlot[1] <- legendPlot[2] - legend.width
     pr <- (legendPlot[4] - legendPlot[3]) * ((1 - legend.shrink)/2)
     legendPlot[4] <- legendPlot[4] - pr
     legendPlot[3] <- legendPlot[3] + pr
 	
-    bp <- par$plt
+    bp <- pars$plt
     bp[2] <- min(bp[2], legendPlot[1] - offset)
 	aspbp = (bp[4]-bp[3]) / (bp[2]-bp[1])
 	adj = aspbp / asp
@@ -36,12 +36,11 @@
 	} else {
 		adjust = (bp[4]-bp[3]) / adj - ((bp[4]-bp[3]))	
 	}
-	adjust = adjust / 2
-bp
-	bp[3] = bp[3] + adjust
-	bp[4] = bp[4] - adjust	
-  bp
-  
+	adjust <- adjust / 2
+
+	bp[3] <- bp[3] + adjust
+	bp[4] <- bp[4] - adjust
+
 	dp <- legendPlot[2] - legendPlot[1]
     legendPlot[1] <- min(bp[2] + 0.5 * offset, legendPlot[1])
     legendPlot[2] <- legendPlot[1] + dp
@@ -77,12 +76,12 @@ bp
 		} else {
 			if (legend.at == 'quantile') {
 				z <- z[is.finite(z)]
-				at = quantile(z, names=F, na.rm=TRUE)
+				at = stats::quantile(z, names=F, na.rm=TRUE)
 				axis.args <- c(list(side = ifelse(horizontal, 1, 4), mgp = c(3, 1, 0), las = ifelse(horizontal, 0, 2), at=at), axis.args)				
 #				at <- c(0, 1:5 * (1/5))
 #				at <- minz + zrange * at
 			} else {
-				at <- axTicks(2, c(minz, maxz, 4))
+				at <- graphics::axTicks(2, c(minz, maxz, 4))
 			}
 			at <- round(at, decs)
 			axis.args <- c(list(side = ifelse(horizontal, 1, 4), mgp = c(3, 1, 0), las = ifelse(horizontal, 0, 2), at=at), axis.args)						
@@ -103,22 +102,22 @@ bp
 		}
 		axis.args = c(axis.args, cex.axis=0.75, tcl=-0.15, list(mgp=c(3, 0.4, 0)) )
 		do.call("axis", axis.args)
-		#axis(axis.args$side, at=min(iz), las=ifelse(horizontal, 0, 2))
-		box()
+		#graphics::axis(axis.args$side, at=min(iz), las=ifelse(horizontal, 0, 2))
+		graphics::box()
 	
 		# title(main = list(legend.lab, cex=1, font=1))
 		if (!is.null(legend.lab)) {
-			# mtext(legend.lab, side=3, line=0.75)
+			# graphics::mtext(legend.lab, side=3, line=0.75)
 			#legend.args <- list(text = legend.lab, side = ifelse(horizontal, 1, 4), line = legend.mar - 2)
 			legend.args <- list(text = legend.lab, side=3, line=0.75)
 		}
 		if (!is.null(legend.args)) {
-			#do.call(mtext, legend.args)
+			#do.call(graphics::mtext, legend.args)
 		}
 	}
 
 
-.plot2 <- function(x, maxpixels=100000, col=rev(terrain.colors(25)), xlab='', ylab='', asp, box=TRUE, add=FALSE, legend=TRUE, legend.at='', ...)  {
+.plot2 <- function(x, maxpixels=100000, col=rev(grDevices::terrain.colors(25)), xlab='', ylab='', asp, box=TRUE, add=FALSE, legend=TRUE, legend.at='', ...)  {
 		
 
 	if (!add & missing(asp)) {
@@ -134,8 +133,8 @@ bp
 
 	x <- sampleRegular(x, maxpixels, asRaster=TRUE, useGDAL=TRUE)
 
-	xticks <- axTicks(1, c(xmin(x), xmax(x), 4))
-	yticks <- axTicks(2, c(ymin(x), ymax(x), 4))
+	xticks <- graphics::axTicks(1, c(xmin(x), xmax(x), 4))
+	yticks <- graphics::axTicks(2, c(ymin(x), ymax(x), 4))
 	
 	if (xres(x) %% 1 == 0) xticks = round(xticks)
 	if (yres(x) %% 1 == 0) yticks = round(yticks)
@@ -148,17 +147,17 @@ bp
 		image(x=x, y=y, z=z,  col=col, axes=FALSE, xlab=xlab, ylab=ylab, add=TRUE, ...)
 	} else {
 		if (legend) {
-			par(pty = "m", plt=plotArea$legendPlot, err = -1)
+			graphics::par(pty = "m", plt=plotArea$legendPlot, err = -1)
 			.plotLegend(z, col, legend.at=legend.at, ...)
-			par(new=TRUE, plt=plotArea$mainPlot) 
+			graphics::par(new=TRUE, plt=plotArea$mainPlot) 
 		}
 		image(x=x, y=y, z=z,  col=col, axes=FALSE, xlab=xlab, ylab=ylab, asp=asp, ...)
-		axis(1, at=xticks,  cex.axis=0.67, tcl=-0.3, mgp=c(3, 0.25, 0))
+		graphics::axis(1, at=xticks,  cex.axis=0.67, tcl=-0.3, mgp=c(3, 0.25, 0))
 		las = ifelse(max(nchar(as.character(yticks)))> 5, 0, 1)
-		axis(2, at=yticks, las = las,  cex.axis=0.67, tcl=-0.3, mgp=c(3, 0.75, 0) )
-		#axis(3, at=xticks, labels=FALSE, lwd.ticks=0)
-		#axis(4, at=yticks, labels=FALSE, lwd.ticks=0)
-		if (box) box()
+		graphics::axis(2, at=yticks, las = las,  cex.axis=0.67, tcl=-0.3, mgp=c(3, 0.75, 0) )
+		#graphics::axis(3, at=xticks, labels=FALSE, lwd.ticks=0)
+		#graphics::axis(4, at=yticks, labels=FALSE, lwd.ticks=0)
+		if (box) graphics::box()
 	}
 }
 
