@@ -1,11 +1,11 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date: Sept 2009
 # Version 0.9
 # Licence GPL v3
 
 
 
-.plotraster <- function(object, col=rev(terrain.colors(25)), maxpixels=100000, axes=TRUE, xlab='', ylab='', ext=NULL, asp, xlim, ylim, add=FALSE, addfun=NULL, main, ...) {
+.plotraster <- function(object, col=rev(grDevices::terrain.colors(25)), maxpixels=100000, axes=TRUE, xlab='', ylab='', ext=NULL, asp, xlim, ylim, add=FALSE, addfun=NULL, main, ...) {
 
   	if (missing(asp)) {
 		if (couldBeLonLat(object, warnings=FALSE)) {
