@@ -29,7 +29,7 @@ setMethod('.quad', signature(x='Extent'),
 		nc = as.integer(round(ncols))
 		if (nc < 1) { stop("ncols should be > 0") }
 		if (nr < 1) { stop("nrows should be > 0") }
-		b <- new("RasterQuadBrick", extent=bb, ncols=nc, nrows=nr)
+		b <- methods::new("RasterQuadBrick", extent=bb, ncols=nc, nrows=nr)
 		projection(b) <- crs
 		levels <- as.integer(max(round(levels), 0))
 		steps <- as.integer(max(round(steps), 0))
