@@ -52,7 +52,7 @@ setMethod('text', signature(x='SpatialPolygons'),
 		}
 		
 		if (length(labels)  == 1) {
-			if (.hasSlot(x, 'data')) {
+			if (methods::.hasSlot(x, 'data')) {
 				if (labels %in% names(x)) {
 					labels <- x@data[, labels]
 				}
@@ -78,7 +78,7 @@ setMethod('text', signature(x='SpatialPoints'),
 		}
 		
 		if (length(labels)  == 1) {
-			if (.hasSlot(x, 'data')) {
+			if (methods::.hasSlot(x, 'data')) {
 				if (labels %in% names(x)) {
 					labels <- x@data[, labels]
 				}
