@@ -12,7 +12,7 @@
 		levels(y) <- levels(x)
 		x <- getValues(x)
 		if (setStatistics) { 
-			stat <- t(apply(x, 2, function(z, ...) cbind(mean(z, na.rm=TRUE), sd(z, na.rm=TRUE))))
+			stat <- t(apply(x, 2, function(z, ...) cbind(mean(z, na.rm=TRUE), stats::sd(z, na.rm=TRUE))))
 		}
 	} else {
 		y <- raster(x)
@@ -20,7 +20,7 @@
 		y@legend@colortable <- x@legend@colortable
 		x <- getValues(x)
 		if (setStatistics) { 
-			stat <- cbind(mean(x, na.rm=TRUE), sd(x, na.rm=TRUE))
+			stat <- cbind(mean(x, na.rm=TRUE), stats::sd(x, na.rm=TRUE))
 		}
 	}
 	
